import { Component, Input, Output, EventEmitter, AfterViewChecked } from '@angular/core';
import { Exercise } from 'app/shared/model/exercise.model';
import { SearchService } from 'app/search/service/search-service';
import { WatchlistManager } from 'app/shared/watchlist/watchlist-manager';
import { LikesService } from 'app/entities/likes/likes.service';
import { ExerciseService } from '../service/exercise.service';

@Component({
  selector: 'jhi-exercise-card',
  templateUrl: './exercise-card.component.html',
  styleUrls: ['./exercise-card.component.scss'],
})
export class ExerciseCardComponent implements AfterViewChecked {
  @Input() exercise: Exercise | undefined;
  @Input() autoOpenDetails = false; // if true opens details dialog automatically

  @Output() exerciseSelectionEvent = new EventEmitter<Exercise>();

  constructor(
    protected searchService: SearchService,
    private watchlistManager: WatchlistManager,
    private likesService: LikesService,
    private exerciseService: ExerciseService
  ) {}

  ngAfterViewChecked(): void {
    if (this.autoOpenDetails) {
      const button = document.querySelector('.exerciseDetailButton');
      if (button instanceof HTMLElement) {
        button.click();
        this.autoOpenDetails = false;
      }
    }
  }
  selectExercise(): void {
    this.exercise = this.exerciseService.populateExerciseWithData(this.exercise!);
    this.exerciseSelectionEvent.emit(this.exercise);
  }

  isOnCurrentWatchlist(e: Exercise): boolean {
    return this.watchlistManager.isExerciseOnCurrentWatchlist(e);
  }

  handleForCurrentWatchlist(e: Exercise): void {
    this.watchlistManager.handleCheckForCurrentWatchlist(e);
  }

  /**
   * correct missing image urls
   */
  correctImageURL(event: Event): void {
    const img = event.srcElement as HTMLImageElement;
    if (img) {
      img.src = '/content/images/Logo_codeAbility_4c_300dpi_RGB3.gif';
    }
  }
}
